@@ -15,6 +15,12 @@
 #' @param epub_version Whether to use version 3 or 2 of EPUB.
 #' @param md_extensions A character string of Pandoc Markdown extensions.
 #' @param pandoc_args A vector of additional Pandoc arguments.
+#' @param template Pandoc template to use for rendering. Pass \code{"default"}
+#'   to use Pandoc's built-in template; pass a path to use a custom template.
+#'   The default pandoc template should be sufficient for most use cases. In
+#'   case you want to develop a custom template, we highly recommend to start
+#'   from the default EPUB templates at
+#'   \url{https://github.com/jgm/pandoc-templates/}.
 #' @note Figure/table numbers cannot be generated if sections are not numbered
 #'   (\code{number_sections = FALSE}).
 #' @export
@@ -22,9 +28,9 @@ epub_book = function(
   fig_width = 5, fig_height = 4, dev = 'png', fig_caption = TRUE,
   number_sections = TRUE, toc = FALSE, toc_depth = 3, stylesheet = NULL,
   cover_image = NULL, metadata = NULL, chapter_level = 1,
-  epub_version = c('epub3', 'epub'), md_extensions = NULL, pandoc_args = NULL
+  epub_version = c('epub3', 'epub'), md_extensions = NULL, pandoc_args = NULL,
+  template = 'default'
 ) {
-
   epub_version = match.arg(epub_version)
   args = c(
     pandoc_args,
@@ -33,6 +39,7 @@ epub_book = function(
     if (!missing(toc_depth)) c('--toc-depth', toc_depth),
     if (!is.null(cover_image)) c('--epub-cover-image', cover_image),
     if (!is.null(metadata)) c('--epub-metadata', metadata),
+    if (!identical(template, 'default')) c('--template', template),
     if (!missing(chapter_level)) c('--epub-chapter-level', chapter_level)
   )
   if (is.null(stylesheet)) css = NULL else {
@@ -50,7 +57,7 @@ epub_book = function(
       NULL
     },
     post_processor = function(metadata, input, output, clean, verbose) {
-      unlink(css)
+      if (length(css)) file.remove(css)
       move_output(output)
     }
   )
@@ -68,17 +75,17 @@ move_output = function(output) {
 
 process_markdown = function(input_file, from, pandoc_args, global, to_md = output_md()) {
   intermediate_html = with_ext(input_file, 'tmp.html')
-  on.exit(unlink(intermediate_html), add = TRUE)
+  on.exit(file.remove(intermediate_html), add = TRUE)
   rmarkdown::pandoc_convert(
-    input_file, 'html4', from, intermediate_html, TRUE,
+    input_file, 'html', from, intermediate_html, TRUE,
     c(pandoc_args, '--section-divs', '--mathjax', '--number-sections')
   )
   x = read_utf8(intermediate_html)
   figs = parse_fig_labels(x, global)
   # resolve cross-references and update the Markdown input file
-  content = resolve_refs_md(
-    read_utf8(input_file), c(figs$ref_table, parse_section_labels(x)), to_md
-  )
+  content = read_utf8(input_file)
+  i = xfun::prose_index(content)
+  content[i] = resolve_refs_md(content[i], c(figs$ref_table, parse_section_labels(x)), to_md)
   if (to_md) content = gsub(
     '^\\\\BeginKnitrBlock\\{[^}]+\\}|\\\\EndKnitrBlock\\{[^}]+\\}$', '', content
   )
